@@ -62,5 +62,9 @@ class Config(object):
         except Exception:
             self.CONF = ConfigSectionsObject("")
 
+    def publicdir(self, pcode, acode):
+        return os.path.abspath(os.path.join(
+            self.CONF.datadir, "..", "..", ".public", pcode, acode))
+
     def refresh(self, path):
         self.CONF = ConfigSectionsObject(path)
