@@ -38,11 +38,11 @@ def getconnection(url):
 
 def init_engine(db_name, dec_base, charset=None):
     # the following code is just for the SQLITE databases
-    from sqlalchemy.interfaces import PoolListener
+    # from sqlalchemy.interfaces import PoolListener
 
-    class ForeignKeysListener(PoolListener):
-        def connect(self, dbapi_con, con_record):
-            dbapi_con.execute('pragma foreign_keys=ON')
+    # class ForeignKeysListener(PoolListener):
+    #     def connect(self, dbapi_con, con_record):
+    #         dbapi_con.execute('pragma foreign_keys=ON')
 
     sqa_cfg = getattr(cfg.CONF, "sqlalchemy", None)
     if not sqa_cfg:
@@ -53,7 +53,7 @@ def init_engine(db_name, dec_base, charset=None):
 
     kwargs = {"echo": getattr(sqa_cfg, "debug", "false").lower() == 'true'}
     if url.startswith("sqlite://"):
-        kwargs["listeners"] = [ForeignKeysListener()]
+        # kwargs["listeners"] = [ForeignKeysListener()]
         kwargs['poolclass'] = sqlalchemy.pool.StaticPool
         kwargs['connect_args'] = {'check_same_thread': False}
     elif charset:
