@@ -15,6 +15,10 @@ import sys
 import six
 # from threading import Timer
 import mimetypes
+if sys.version_info[0] == 3:
+    import urllib.parse as urllib_parse
+else:
+    import urllib as urllib_parse
 
 import paste.deploy
 import grp
@@ -119,17 +123,24 @@ def cleanup():
     # Timer(CLEANUP_WAIT_PERIOD, terminate_now, ()).start()
 
 
+class UnixDomainHttpProtocol(eventlet.wsgi.HttpProtocol):
+    def __init__(self, request, client_address, server):
+        if client_address == '':
+            client_address = ('<local>', 0)
+        # base class is old-style, no super does not work properly
+        eventlet.wsgi.HttpProtocol.__init__(self, request, client_address,
+                                            server)
+    def get_environ(self):
+        env = super(UnixDomainHttpProtocol, self).get_environ()
+        # without this, any unicode character passed to the url path is
+        # throws an error
+        env['PATH_INFO'] = urllib_parse.unquote(env['RAW_PATH_INFO'], 'iso-8859-1')
+        return env
+
+
 class WSGIServer(object):
     _instance = None
 
-    class UnixDomainHttpProtocol(eventlet.wsgi.HttpProtocol):
-        def __init__(self, request, client_address, server):
-            if client_address == '':
-                client_address = ('<local>', 0)
-            # base class is old-style, no super does not work properly
-            eventlet.wsgi.HttpProtocol.__init__(self, request, client_address,
-                                                server)
-
     def _register_app_optgroup(self, app_name):
         return getattr(cfg.CONF, app_name)
 
@@ -291,6 +302,7 @@ paste.app_factory = %(factory)s
                     sys.exit(-1)
         else:
             self._app = paste.deploy.loadapp("config:" + self._paste_ini)
+
             global wsgi_listener
             wsgi_listener = eventlet.spawn(
                 self._run_server, self._app, self._sock)
@@ -309,9 +321,10 @@ paste.app_factory = %(factory)s
         logging.info("Starting the server")
         log = open("/dev/null", "w+")
         from greenlet import GreenletExit
+
         try:
             eventlet.wsgi.server(sock, app, custom_pool=self._pool,
-                                 protocol=self.UnixDomainHttpProtocol,
+                                 protocol=UnixDomainHttpProtocol,
                                  log_output=False, log=log,
                                  debug=True)
         except GreenletExit:
@@ -387,6 +400,10 @@ class BaseHandler(object):
         for h in hardcoded:
             route.pop(h)
 
+        for k, v in route.items():
+            # negating the effect of url path decoding in UnixDomainHttpProtocol
+            route[k] = v.encode('iso-8859-1').decode('utf8')
+
         return self.respond(action, request, custom_serializer,
                             custom_deserializer, inp_data_qualifier, **route)
 
